library(gnlm)
library(event)

interf <- read.table("interfer.dat",skip=14,head=T)
attach(interf)
treat <- 2-treat
times <- read.list("intert.dat",skip=5,nline=1)
tt <- list()
birth <- vt <- censor <- gp <- ag <- tr <- id <- NULL
j <- 0
for(i in times){
	j <- j+1
	id <- c(id,rep(j,length(i)))
	tt <- c(tt,list(c(i[1],diff(i))))
	vt <- c(vt,i[1],diff(i))
	birth <- c(birth,log(1:length(i)))
	censor <- c(censor,rep(1,length(i)))
	censor[length(censor)] <- cens[j]
	tr <- c(tr,rep(treat[j],length(i)))
	ag <- c(ag,rep(age[j],length(i)))
	tmp <- rep(2+treat[j],length(i))
	tmp[1] <- treat[j]
	gp <- c(gp,tmp)}
tt <- restovec(tt,cens=cens)

y <- pp(vt,cens=censor)
ptr <- tccov(vt,treat,id)
page <- tccov(vt,age,id)
tp <- tpast(vt)
n <- bp(vt,id)

# exponential
ehr(y,plambda=-5)
ehr(y,plambda=c(-5.8,-1),lambda=~ptr)
ehr(y,plambda=c(-5.8,-0.025),lambda=~page)

# Weibull
ehr(y,plambda=c(-5.8,-0.1),lambda=~log(tp))
ehr(y,plambda=c(-5.85,0,-1.14),lambda=~log(tp)+ptr)
ehr(y,plambda=c(-6.1,-0.01,-0.025),lambda=~log(tp)+page)

# exponential birth
ehr(y,plambda=c(-5.8,0.4),lambda=~log(n+1))
ehr(y,plambda=c(-5.8,-0.1,0.3),lambda=~ptr+log(n+1))
ehr(y,plambda=c(-6,-1,0.3,0.5),lambda=~ptr*log(n+1))
ehr(y,plambda=c(-5.8,-0.02,0.3),lambda=~page+log(n+1))

# Weibull birth
ehr(y,plambda=c(-6.1,0,0.4),lambda=~log(tp)+log(n+1))
ehr(y,plambda=c(-6.2,-0.05,-1,0.3),lambda=~log(tp)+ptr+log(n+1))
ehr(y,plambda=c(-6.2,-0.05,-1,0.3,0.5),lambda=~log(tp)+ptr*log(n+1))
ehr(y,plambda=c(-6.2,0.025,-0.022,1.15),lambda=~log(tp)+page+log(n+1))

ehr(y,plambda=c(-5.8,-1,0.3),lambda=~ptr+(n>0))

# same with gnlr
mu <- function(p,linear) exp(linear)
gnlr(cbind(vt,censor),"exponential",mu=~1,pmu=400)
gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~tr,pmu=c(6,0))
gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~ag,pmu=c(6,0))

gnlr(cbind(vt,censor),"Weibull",mu=~1,pmu=400,psh=-0.1)
gnlr(cbind(vt,censor),"Weibull",mu=mu,linear=~tr,pmu=c(6,0),psh=-0.1)
gnlr(cbind(vt,censor),"Weibull",mu=mu,linear=~ag,pmu=c(5,0),psh=-0.1)

gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~birth,pmu=c(6,0))
gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~tr+birth,pmu=c(6,0,0))
gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~tr*birth,pmu=c(6,0,0,0))
gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~ag+birth,pmu=c(6,0,0))

gnlr(cbind(vt,censor),"Weibull",mu=mu,linear=~birth,pmu=c(6,0),psh=-0.1)
gnlr(cbind(vt,censor),"Weibull",mu=mu,linear=~tr+birth,pmu=c(6,0,0),psh=-0.1)
gnlr(cbind(vt,censor),"Weibull",mu=mu,linear=~tr*birth,pmu=c(6,0,0,0),psh=-0.1)
gnlr(cbind(vt,censor),"Weibull",mu=mu,linear=~ag+birth,pmu=c(6,0,0),psh=-0.1)

gnlr(cbind(vt,censor),"exponential",mu=mu,linear=~tr+(exp(birth)>1),
	pmu=c(6,0,0))

if(interactive()){
postscript("interfer.eps",height=5,width=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(km(vt,censor=censor,group=gp),main=NULL,xlab="Days",
	ylab="Reinfection probability")
lines(seq(1,400,by=10),1-pexp(seq(1,400,by=10),exp(-6.1549-0.8089)))
lines(seq(1,400,by=10),1-pexp(seq(1,400,by=10),exp(-6.1549)),lty=2)
lines(seq(1,400,by=10),1-pexp(seq(1,400,by=10),
	exp(-6.1549-0.8089+0.9858*log(3))),lty=3)
lines(seq(1,400,by=10),1-pexp(seq(1,400,by=10),exp(-6.1549+0.9858*log(3))),
	lty=4)
legend(-15,0.5,legend=c("First infection","Interferon","Placebo",
	"Subsequent infections","Interferon","Placebo"),
	lty=c(0,1,2,0,3,4),bty="n")
dev.off()
}
