library(gnlm)
library(event)
library(repeated)

surv <- read.surv("mammary.dat",skip=11)
treat <- c(rep(0,23),rep(1,25))
resp <- restovec(surv[[1]],cens=surv[[2]])

cn <- rep(1,length(response(resp)[,1]))
cn[cumsum(nobs(resp))] <- surv[[2]]
for(i in 1:(length(response(resp)[,1])-1))if(response(resp)[i,1]==0){
	cn[i-1] <- if(response(resp)[i+1,1]==0) 3 else 2}
yy <- pp(response(resp)[response(resp)[,1]>0,1],
	censor=cn[response(resp)[,1]>0])
tt <- tpast(response(resp)[response(resp)[,1]>0,1])
trt <- c(rep(0,4186),rep(1,4550))
bir <- log(bp(response(resp)[response(resp)[,1]>0,1],
	covind(resp)[response(resp)[,1]>0],cens=cn[response(resp)[,1]>0])+1)

# independence
ehr(yy,plambda=-3)
ehr(yy,plambda=c(-3,0),lambda=~log(tt))
lambda <- function(p)hgamma(tt,p[2],exp(p[1]))
ehr(yy,plambda=c(3.9,1),lambda=lambda)
ehr(yy,plambda=c(-3,0),lambda=~trt)
ehr(yy,plambda=c(-4,0,1),lambda=~log(tt)+trt)
lambda <- function(p)hgamma(tt,p[3],exp(p[1]+p[2]*trt))
ehr(yy,plambda=c(6,-2,1),lambda=lambda)
ehr(yy,plambda=c(-3,0,0),lambda=~trt+bir)
ehr(yy,plambda=c(-4,0,1,0),lambda=~log(tt)+trt+bir)
lambda <- function(p)hgamma(tt,p[4],exp(p[1]+p[2]*trt+p[3]*bir))
ehr(yy,plambda=c(4.4,-1,0,1),lambda=lambda)

# gamma mixing
# independence
print(zei <- kalsurv(resp,pinit=0.1,preg=4,cens=cens,dep="independence"))
print(zwi <- kalsurv(resp,pinit=0.35,preg=3.5,psh=1.07,cens=cens,
	intensity="Weibull",dep="independence",stepmax=0.1))
print(zgi <- kalsurv(resp,pinit=1,preg=2,psh=2.15,cens=cens,
	intensity="gamma",dep="independence"))
print(zeit <- kalsurv(resp,ccov=treat,pinit=0.7,preg=c(4,1),cens=cens,
	dep="independence"))
print(zwit <- kalsurv(resp,ccov=treat,pinit=0.29,psh=1.09,preg=c(4,-0.8),
	cens=cens,dep="independence",intensity="Weibull",stepmax=0.1))
print(zgit <- kalsurv(resp,ccov=treat,pinit=2,psh=2,
	preg=c(4,0),cens=cens,intensity="gamma",dep="independence"))
print(zeitb <- kalsurv(resp,ccov=treat,pinit=0.7,preg=c(4,1),cens=cens,
	dep="independence",pbirth=0))
print(zwitb <- kalsurv(resp,ccov=treat,pinit=0.7,psh=2,preg=c(4,-0.2),
	cens=cens,dep="independence",intensity="Weibull",pbirth=-1))
print(zgitb <- kalsurv(resp,ccov=treat,pinit=2,psh=2,
	preg=c(4,0.8),pbirth=0,cens=cens,intensity="gamma",dep="independence"))

# frailty
print(ze <- kalsurv(resp,pinit=0.7,preg=4,cens=cens,dep="frailty"))
print(zw <- kalsurv(resp,pinit=0.7,preg=4,psh=1,cens=cens,
	intensity="Weibull",dep="frailty"))
print(zg <- kalsurv(resp,pinit=0.26,preg=4,psh=1,cens=cens,
	intensity="gamma",dep="frailty"))
print(zet <- kalsurv(resp,ccov=treat,pinit=0.7,preg=c(4,1),cens=cens,
	dep="frailty"))
print(zwt <- kalsurv(resp,ccov=treat,pinit=0.7,preg=c(4,1),psh=1,
	cens=cens,intensity="Weibull",dep="frailty"))
print(zgt <- kalsurv(resp,ccov=treat,pinit=0.5,preg=c(4,-0.5),psh=1,
	cens=cens,intensity="gamma",dep="frailty"))
print(zetb <- kalsurv(resp,ccov=treat,pinit=0.7,preg=c(4,1),cens=cens,
	pbirth=0,dep="frailty"))
print(zwtb <- kalsurv(resp,ccov=treat,pinit=0.1,preg=c(4,1),psh=1,
	cens=cens,intensity="Weibull",pbirth=0,dep="frailty"))
print(zgtb <- kalsurv(resp,ccov=treat,pinit=0.05,preg=c(4.3,-0.2),psh=1,
	cens=cens,intensity="gamma",pbirth=-0.7,dep="frailty"))

# Markov
print(zem <- kalsurv(resp,pinit=0.7,pdep=0.9,preg=4,cens=cens,
	dep="serial",upd="Markov"))
print(zwm <- kalsurv(resp,pinit=0.7,pdep=0.9,preg=4,psh=1.4,cens=cens,
	intensity="Weibull",dep="serial",upd="Markov"))
print(zgm <- kalsurv(resp,pinit=1,pdep=0.7,preg=2,psh=2.5,cens=cens,
	intensity="gamma",dep="serial",upd="Markov"))
print(zemt <- kalsurv(resp,ccov=treat,pinit=0.7,pdep=0.5,preg=c(4,1),
	cens=cens,dep="serial",upd="Markov"))
print(zwmt <- kalsurv(resp,ccov=treat,pinit=0.7,pdep=0.9,psh=1.3,
	preg=c(4,0.3),cens=cens,intensity="Weibull",dep="serial",upd="Markov"))
print(zgmt <- kalsurv(resp,ccov=treat,pinit=1,pdep=0.9,dep="serial",
	psh=1.5,preg=c(4,-0.8),cens=cens,intensity="gamma",upd="Markov"))
print(zemtb <- kalsurv(resp,ccov=treat,pinit=0.7,pdep=0.5,preg=c(4,1),
	cens=cens,dep="serial",upd="Markov",pbirth=-1))
print(zwmtb <- kalsurv(resp,ccov=treat,pinit=1,pdep=0.9,psh=1.4,preg=c(4,-0.7),
	cens=cens,intensity="Weibull",dep="serial",upd="Markov",pbirth=-1))
print(zgmtb <- kalsurv(resp,ccov=treat,pinit=0.1,pdep=0.5,pbirth=0,psh=1,
	preg=c(4,-0.8),cens=cens,intensity="gamma",dep="serial",upd="Markov"))

# normal mixing
yy <- rep(0,length(response(resp)[,1]))
for(i in 1:length(response(resp)[,1])){
	if(response(resp)[i,1]>0)yy[i] <- response(resp)[i,1]
	else yy[i] <- yy[i-1]}
cn <- rep(1,length(response(resp)[,1]))
cn[cumsum(nobs(resp))] <- surv[[2]]
y <- cbind(yy,cn)
nest <- covind(resp)
tr <- c(rep(0,81),rep(1,173))
birth <- log(sequence(nobs(resp)))
gnlmm(y,"exponential",pmu=35,delta=cn,nest=nest,psd=0.1,points=7)
gnlmm(y,"Weibull",pmu=35,pshape=0,delta=cn,nest=nest,psd=0.1,points=5)
gnlmm(y,"gamma",pmu=35,pshape=0,delta=cn,nest=nest,psd=0.1,points=5)
mu <- function(p) exp(p[1]+p[2]*tr)
gnlmm(y,"exponential",pmu=c(4.25,-0.5),mu=mu,delta=cn,nest=nest,
	psd=0.1,points=5)
gnlmm(y,"Weibull",pmu=c(4.3,-0.7),pshape=0,mu=mu,delta=cn,nest=nest,
	psd=0.36,points=5)
gnlmm(y,"gamma",pmu=c(4.3,-0.7),pshape=0,mu=mu,delta=cn,nest=nest,
	psd=0.36,points=5)
mu <- function(p) exp(p[1]+p[2]*tr+p[3]*birth)
gnlmm(y,"exponential",pmu=c(4.25,-0.5,-0.7),mu=mu,delta=cn,nest=nest,
	psd=0.1,points=5)
gnlmm(y,"Weibull",pmu=c(4.3,-0.7,-0.7),pshape=0,mu=mu,delta=cn,
	nest=nest,psd=0.36,points=5)
gnlmm(y,"gamma",pmu=c(4.3,-0.7,-0.7),pshape=0,mu=mu,delta=cn,
	nest=nest,psd=0.36,points=5)

if(interactive()){
gp <- 2*tr+(sequence(nobs(resp))!=1)
times <- seq(1,185,by=5)
postscript("mammary.eps",height=5)
par(mfrow=c(1,2),mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(km(yy,censor=cn,group=gp),main="",xlab="Days",
	ylab="Tumour nonrecurrence probability")
# kalsurv Weibull
lines(times,exp(zwitb$coef[4])/(exp(zwitb$coef[4])+(times/
	exp(zwitb$coef[1]))^exp(zwitb$coef[5])))
lines(times,exp(zwitb$coef[4])/(exp(zwitb$coef[4])+(times/
	exp(zwitb$coef[1]+zwitb$coef[2]))^exp(zwitb$coef[5])),lty=3)
lines(times,exp(zwitb$coef[4])/(exp(zwitb$coef[4])+(times/
	exp(zwitb$coef[1]+zwitb$coef[3]*log(3)))^exp(zwitb$coef[5])),lty=2)
lines(times,exp(zwitb$coef[4])/(exp(zwitb$coef[4])+(times/
	exp(zwitb$coef[1]+zwitb$coef[2]+zwitb$coef[3]*log(3)))^
	exp(zwitb$coef[5])),lty=4)
plot(times,exp(zwitb$coef[4])*exp(zwitb$coef[5])*(times/
	exp(zwitb$coef[1]))^(exp(zwitb$coef[5])-1)/
	exp(zwitb$coef[1])/(exp(zwitb$coef[4])+
	(times/exp(zwitb$coef[1]))^exp(zwitb$coef[5])),type="l",
	ylim=c(0,0.15),xlab="Days",ylab="Intensity function")
lines(times,exp(zwitb$coef[4])*exp(zwitb$coef[5])*(times/
	exp(zwitb$coef[1]+zwitb$coef[2]))^(exp(zwitb$coef[5])-1)/
	exp(zwitb$coef[1]+zwitb$coef[2])/(exp(zwitb$coef[4])+
	(times/exp(zwitb$coef[1]+zwitb$coef[2]))^exp(zwitb$coef[5])),lty=3)
lines(times,exp(zwitb$coef[4])*exp(zwitb$coef[5])*(times/
	exp(zwitb$coef[1]+zwitb$coef[3]*log(3)))^(exp(zwitb$coef[5])-1)/
	exp(zwitb$coef[1]+zwitb$coef[3]*log(3))/(exp(zwitb$coef[4])+
	(times/exp(zwitb$coef[1]+zwitb$coef[3]*log(3)))^exp(zwitb$coef[5])),
	lty=2)
lines(times,exp(zwitb$coef[4])*exp(zwitb$coef[5])*(times/
	exp(zwitb$coef[1]+zwitb$coef[2]+zwitb$coef[3]*log(3)))^
	(exp(zwitb$coef[5])-1)/exp(zwitb$coef[1]+zwitb$coef[2]+
	zwitb$coef[3]*log(3))/(exp(zwitb$coef[4])+
	(times/exp(zwitb$coef[1]+zwitb$coef[2]+
	zwitb$coef[3]*log(3)))^exp(zwitb$coef[5])),lty=4)
legend(90,0.16,legend=c("First tumour","Retinoid","Control",
	"Subsequent","  tumours","Retinoid","Control"),
	lty=c("",1,3,"",2,4),bty="n")
dev.off()
postscript("mammary2.eps",height=5)
par(mfrow=c(1,2),font.main=1,mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot(0,0,ylim=c(0,100),xlim=c(60,190),type="n",xlab="Total days elapsed",
	ylab="Days between tumours",main="Retinoid",xaxt="n")
axis(1,c(60,100,140,180))
plot(iprofile(zwitb),nind=7,add=T,pch=21,lty=1)
plot(iprofile(zwitb),nind=10,add=T,pch=22,lty=2)
plot(iprofile(zwitb),nind=21,add=T,pch=23,lty=3)
legend(150,100,legend=c("  7","10","21"),lty=1:3,pch=21:23,bty="n")
plot(0,0,ylim=c(0,100),xlim=c(60,190),type="n",xlab="Total days elapsed",
	ylab="",main="Control",xaxt="n")
axis(1,c(60,100,140,180))
plot(iprofile(zwitb),nind=26,add=T,pch=21,lty=1)
plot(iprofile(zwitb),nind=28,add=T,pch=22,lty=2)
plot(iprofile(zwitb),nind=34,add=T,pch=23,lty=3)
legend(150,100,legend=c("26","28","34"),lty=1:3,pch=21:23,bty="n")
dev.off()
}
