library(event)
library(gnlm)

data <- read.table("beck.dat",skip=4,header=T)
attach(data)
tt <- list(matrix(diff(time[1:82])),matrix(diff(time[83:160])))
mag <- list(matrix(magnitude[1:81]),matrix(magnitude[83:159]))
# adjust Great Eggleshope Beck to start at same time as Carl Beck
time[1:82] <- time[1:82]+64
trend <- list(matrix(time[2:82]),matrix(time[84:160]))
trm <- list(cbind(time[2:82],magnitude[1:81]),
	cbind(time[84:160],magnitude[83:159]))
colnames(trm[[1]]) <- c("trend","magnitude")
tvc2 <-list(cbind(magnitude[1:81],cos(2*pi*time[2:82]/365.25),
	sin(2*pi*time[2:82]/365.25)),cbind(magnitude[83:159],
	cos(2*pi*time[84:160]/365.25),sin(2*pi*time[84:160]/365.25)))
colnames(tvc2[[1]]) <- c("magnitude","cos1","sin1")
tvc3 <-list(cbind(tvc2[[1]],cos(4*pi*time[2:82]/365.25),
	sin(4*pi*time[2:82]/365.25)),cbind(tvc2[[2]],
	cos(4*pi*time[84:160]/365.25),sin(4*pi*time[84:160]/365.25)))
colnames(tvc3[[1]]) <- c("magnitude","cos1","sin1","cos2","sin2")
tvc4 <- list(tvc2[[1]][,2:3],tvc2[[2]][,2:3])
tvc5 <- list(tvc3[[1]][,2:5],tvc3[[2]][,2:5])
tvc4tr <- list(cbind(tvc2[[1]][,2:3],time[2:82]),
	cbind(tvc2[[2]][,2:3],time[84:160]))
colnames(tvc4tr[[1]]) <- c("cos1","sin1","trend")
tvc5tr <- list(cbind(tvc3[[1]][,2:5],time[2:82]),
	cbind(tvc3[[2]][,2:5],time[84:160]))
colnames(tvc5tr[[1]]) <- c("cos1","sin1","cos2","sin2","trend")

cens <- c(1,1)
beck <- c(0,1)
tt <- restovec(tt,cens=cens)

print(zei <- kalsurv(tt,pinit=0.2,preg=3,dep="independence"))
print(zee <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,dep="serial",upd="event"))
print(zeeb <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,
	pbirth=0,dep="serial",upd="event"))
print(zes <- kalsurv(tt,pinit=0.3,pdep=0.9,preg=3,dep="serial",upd="Markov"))
print(zesb <- kalsurv(tt,pinit=0.1,pdep=0.95,preg=11,
	pbirth=0,dep="serial",upd="Markov"))
print(zec <- kalsurv(tt,pinit=0.1,pdep=0.5,preg=3,dep="serial",upd="count"))
print(zecb <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,
	pbirth=0,dep="serial",upd="count"))
#print(zeh <- kalsurv(tt,pinit=0.2,pdep=0.9,preg=3,
#	dep="serial",upd="cumulated"))
print(zek <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,
	dep="serial",upd="kalman"))

print(zeit <- kalsurv(tt,pinit=0.3,dep="independence",
	preg=c(3,1),ccov=beck))
print(zeitb <- kalsurv(tt,pinit=0.3,dep="independence",
	pbirth=0,preg=c(3,1),ccov=beck))
print(zeet <- kalsurv(tt,pinit=0.3,pdep=0.8,upd="event",
	dep="serial",preg=c(3,1),ccov=beck))
print(zeetb <- kalsurv(tt,pinit=0.3,pdep=0.8,
	pbirth=0,dep="serial",upd="event",preg=c(3,1),ccov=beck))
print(zest <- kalsurv(tt,pinit=0.3,pdep=0.8,upd="Markov",
	dep="serial",preg=c(3,1),ccov=beck))
print(zestb <- kalsurv(tt,pinit=0.3,pdep=0.9,
	pbirth=0,dep="serial",upd="Markov",preg=c(3,1),ccov=beck))
print(zect <- kalsurv(tt,pinit=0.3,pdep=0.9,upd="count",
	dep="serial",preg=c(3,1),ccov=beck))
print(zectb <- kalsurv(tt,pinit=0.3,pdep=0.9,upd="count",
	dep="serial",pbirth=0,preg=c(3,1),ccov=beck))
#print(zeht <- kalsurv(tt,pinit=0.3,pdep=0.9,
#	dep="serial",upd="cumulated",preg=c(3,1),ccov=beck))
print(zekt <- kalsurv(tt,pinit=0.3,pdep=0.9,upd="kalman",
	dep="serial",preg=c(3,0.1),ccov=beck))

print(zwi <- kalsurv(tt,pinit=0.3,preg=3,psh=1,
	dep="independence",intensity="Weibull"))
print(zwib <- kalsurv(tt,pinit=0.3,preg=3,psh=1,
	pbirth=0,dep="independence",intensity="Weibull"))
print(zwe <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	dep="serial",upd="event",intensity="Weibull"))
print(zweb <- kalsurv(tt,pinit=0.3,pdep=0.1,preg=5,psh=1,
	pbirth=0,dep="serial",upd="event",intensity="Weibull"))
print(zws <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	dep="serial",upd="Markov",intensity="Weibull"))
print(zwsb <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	pbirth=0,dep="serial",upd="Markov",intensity="Weibull"))
print(zwc <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	dep="serial",upd="count",intensity="Weibull"))
#print(zwh <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
#	dep="serial",upd="cumulated",intensity="Weibull"))
print(zwk <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	dep="serial",upd="kalman",intensity="Weibull"))

print(zwit <- kalsurv(tt,pinit=0.3,psh=1,
	dep="independence",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwitb <- kalsurv(tt,pinit=0.3,psh=1,
	pbirth=0,dep="independence",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwet <- kalsurv(tt,pinit=0.3,pdep=0.5,psh=1,
	dep="serial",upd="event",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwebt <- kalsurv(tt,pinit=0.3,pdep=0.1,psh=1,dep="serial",
	pbirth=0,upd="event",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwst <- kalsurv(tt,pinit=0.3,pdep=0.5,psh=1,
	dep="serial",upd="Markov",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwsbt <- kalsurv(tt,pinit=0.3,pdep=0.5,psh=1,dep="serial",
	pbirth=0,upd="Markov",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwct <- kalsurv(tt,pinit=0.3,pdep=0.5,psh=1,dep="serial",
	upd="count",intensity="Weibull",preg=c(3,1),ccov=beck))
#print(zwht <- kalsurv(tt,pinit=0.3,pdep=0.5,psh=1,dep="serial",
#	upd="cumulated",intensity="Weibull",preg=c(3,1),ccov=beck))
print(zwkt <- kalsurv(tt,pinit=0.3,pdep=0.5,psh=1,
	dep="serial",upd="kalman",intensity="Weibull",preg=c(3,1),ccov=beck))

print(zgi <- kalsurv(tt,pinit=0.3,preg=2,psh=2,dep="independence",
	intensity="gamma"))
print(zgib <- kalsurv(tt,pinit=0.6,preg=2,psh=1.9,
	pbirth=0,dep="independence",intensity="gamma"))
print(zgs <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=2,
	dep="serial",upd="Markov",intensity="gamma"))
print(zgsb <- kalsurv(tt,pinit=1,pdep=0.95,preg=3,psh=2,
	pbirth=0,dep="serial",upd="Markov",intensity="gamma"))
print(zgit <- kalsurv(tt,pinit=0.3,preg=c(3,0),psh=2,
	dep="independence",intensity="gamma",ccov=beck))
print(zgitb <- kalsurv(tt,pinit=0.6,preg=c(3,0),psh=2,
	pbirth=-0.0056,dep="independence",intensity="gamma",ccov=beck))
print(zgst <- kalsurv(tt,pinit=0.3,pdep=0.9,preg=c(3,0),psh=2,
	dep="serial",upd="Markov",intensity="gamma",ccov=beck))
print(zgsbt <- kalsurv(tt,pinit=0.64,pdep=0.94,preg=c(3,0),psh=2.1,
	pbirth=0,dep="serial",upd="Markov",intensity="gamma",ccov=beck))

print(zwlns <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	dep="serial",upd="Markov",intensity="log normal"))
print(zwlnsb <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,psh=1,
	pbirth=0,dep="serial",upd="Markov",intensity="log normal"))

print(zwlls <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,
	dep="serial",upd="Markov",intensity="log logistic"))
print(zwllsb <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,psh=1,
	pbirth=0,dep="serial",upd="Markov",intensity="log logistic"))

print(zwlcs <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,psh=1,
	dep="serial",upd="Markov",intensity="log Cauchy"))
print(zwlcsb <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,psh=1,
	pbirth=0,dep="serial",upd="Markov",intensity="log Cauchy"))

print(zetvi <- kalsurv(tt,pinit=0.16,preg=3,dep="independence",
	tvc=mag,ptvc=0))
print(zwtvi <- kalsurv(tt,pinit=1.2,preg=2.6,psh=1.8,dep="independence",
	intensity="Weibull",tvc=mag,ptvc=0))
print(zwtvs <- kalsurv(tt,pinit=1.3,pdep=0.95,preg=3,psh=1.6,
	dep="serial",upd="Markov",intensity="Weibull",tvc=mag,ptvc=0.001))
print(zwtvsb <- kalsurv(tt,pinit=1.4,pdep=0.94,preg=3,psh=1.6,pbirth=0.001,
	dep="serial",upd="Markov",intensity="Weibull",tvc=mag,ptvc=0.0001))
print(zetvc2i <- kalsurv(tt,pinit=0.3,preg=3,dep="independence",
	tvc=tvc4,ptvc=c(-0.1,-0.1)))
print(zwtvc2i <- kalsurv(tt,pinit=0.3,preg=3,psh=1,
	dep="independence",intensity="Weibull",tvc=tvc4,ptvc=c(-0.1,-0.1)))
print(zwtvc2s <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,dep="serial",
	upd="Markov",intensity="Weibull",tvc=tvc4,ptvc=c(-0.1,-0.1)))
print(zwtvc2sb <- kalsurv(tt,pinit=1.1,pdep=0.95,preg=3,psh=1.5,pbirth=0.2,
	dep="serial",upd="Markov",intensity="Weibull",tvc=tvc4,ptvc=c(0.09,0)))
print(zetvc4i <- kalsurv(tt,pinit=0.3,preg=3,
	dep="independence",tvc=tvc5,ptvc=c(-0.1,-0.1,-0.1,0.1)))
print(zwtvc4i <- kalsurv(tt,pinit=0.3,preg=3,psh=1,dep="independence",
	intensity="Weibull",tvc=tvc5,ptvc=c(-0.1,-0.1,-0.2,0.1)))
print(zwtvc4s <- kalsurv(tt,pinit=0.3,pdep=0.5,preg=3,psh=1,dep="serial",
	upd="Markov",intensity="Weibull",tvc=tvc5,ptvc=c(-0.1,-0.1,-0.1,0.1)))
print(zwtvc4sb <- kalsurv(tt,pinit=0.3,pdep=0.8,preg=3,psh=1,
	pbirth=0,dep="serial",upd="Markov",intensity="Weibull",tvc=tvc5,
	ptvc=c(-0.1,-0.05,-0.1,0.1)))

print(zgtvi <- kalsurv(tt,pinit=1,preg=2,psh=2,
	dep="independence",intensity="gamma",tvc=mag,ptvc=0.001))
print(zgtvs <- kalsurv(tt,pinit=1,pdep=0.5,preg=2.1,psh=2,
	dep="serial",upd="Markov",intensity="gamma",tvc=mag,ptvc=0.001))
print(zgtvsb <- kalsurv(tt,pinit=1,pdep=0.96,preg=3,psh=2,pbirth=0.0001,
	dep="serial",upd="Markov",intensity="gamma",tvc=mag,ptvc=0.0001))
print(zgtvc2i <- kalsurv(tt,pinit=0.3,preg=3,psh=2,
	dep="independence",intensity="gamma",tvc=tvc4,ptvc=c(-0.1,-0.1)))
print(zgtvc2s <- kalsurv(tt,pinit=0.33,pdep=0.8,preg=3,psh=2,dep="serial",
	upd="Markov",intensity="gamma",tvc=tvc4,ptvc=c(-0.1,-0.1)))
print(zgtvc2sb <- kalsurv(tt,pinit=0.63,pdep=0.93,preg=3,psh=2.1,
	pbirth=-0.0055,dep="serial",upd="Markov",intensity="gamma",
	tvc=tvc4,ptvc=c(-0.05,-0.1)))
print(zgtvc4i <- kalsurv(tt,pinit=0.3,preg=3,psh=2,
	dep="independence",intensity="gamma",tvc=tvc5,ptvc=c(-0.1,0,0.1,0.1)))
print(zgtvc4s <- kalsurv(tt,pinit=0.3,pdep=0.9,preg=3,psh=2,dep="serial",
	upd="Markov",intensity="gamma",tvc=tvc5,ptvc=c(0.1,0.03,0,0)))
print(zgtvc4sb <- kalsurv(tt,pinit=1,pdep=0.96,preg=3,psh=2,
	pbirth=0.0001,dep="serial",upd="Markov",intensity="gamma",
	tvc=tvc5,ptvc=c(-0.12,-0.05,0.11,0.08)))
print(zgtri <- kalsurv(tt,pinit=0.6,preg=2,psh=1.9,
	dep="independence",intensity="gamma",tvc=trend,ptvc=0))
print(zgtrs <- kalsurv(tt,pinit=0.6,pdep=0.96,preg=2,psh=1.9,
	dep="serial",upd="Markov",intensity="gamma",tvc=trend,ptvc=0.0005))
print(zgtrsb <- kalsurv(tt,pinit=0.63,pdep=0.93,preg=2,psh=2.1,pbirth=0.0001,
	dep="serial",upd="Markov",intensity="gamma",tvc=trend,ptvc=0.0009))
print(zgtvc4tri <- kalsurv(tt,pinit=0.3,preg=3,psh=2,dep="independence",
	intensity="gamma",tvc=tvc5tr,ptvc=c(-0.1,0,0.1,0.1,0.01)))
print(zgtvc4trs <- kalsurv(tt,pinit=0.3,pdep=0.96,preg=1.5,psh=2,
	dep="serial",upd="Markov",intensity="gamma",tvc=tvc5tr,
	ptvc=c(-0.1,-0.1,-0.2,0,0.0009)))
print(zgtvc4trsb <- kalsurv(tt,pinit=0.3,pdep=0.96,preg=1.5,psh=2,
	pbirth=0,dep="serial",upd="Markov",intensity="gamma",tvc=tvc5tr,
	ptvc=c(-0.1,-0.1,-0.2,0,0.0009)))
print(zgtrmi <- kalsurv(tt,pinit=0.6,preg=1.5,psh=2,
	dep="independence",intensity="gamma",tvc=trm,ptvc=c(0.01,0.01)))
print(zgtrms <- kalsurv(tt,pinit=0.46,pdep=0.93,preg=1.5,psh=2.1,
	dep="serial",upd="Markov",intensity="gamma",tvc=trm,ptvc=c(0.01,0.01)))
print(zgtrmsb <- kalsurv(tt,pinit=0.6,pdep=0.93,preg=2,psh=2,
	pbirth=0,dep="serial",upd="Markov",intensity="gamma",tvc=trm,
	ptvc=c(0.01,0.01)))

y <- tt$y
gnlr(y,"exponential",pmu=25)
gnlr(y,"Weibull",pmu=25,pshape=0)
gnlr(y,"gamma",pmu=25,pshape=0)
bk <- beck[covind(tt)]
mu <- function(p) exp(p[1]+p[2]*bk)
gnlr(y,"exponential",pmu=c(8,-1),mu=mu)
gnlr(y,"Weibull",pmu=c(8,-1),pshape=0,mu=mu)
gnlr(y,"gamma",pmu=c(8,-1),pshape=0,mu=mu)
birth <- log(sequence(tt$nobs))
mu <- function(p) exp(p[1]+p[2]*birth)
gnlr(y,"exponential",pmu=c(8,0),mu=mu)
gnlr(y,"Weibull",pmu=c(8,0),pshape=0,mu=mu)
gnlr(y,"gamma",pmu=c(8,0),pshape=0,mu=mu)
mu <- function(p) exp(p[1]+p[2]*bk+p[3]*birth)
gnlr(y,"exponential",pmu=c(8,-1,0),mu=mu)
gnlr(y,"Weibull",pmu=c(8,-1,0),pshape=0,mu=mu)
gnlr(y,"gamma",pmu=c(8,-1,0),pshape=0,mu=mu)
mu <- function(p) exp(p[1]+p[2]*bk+p[3]*birth+p[4]*bk*birth)
gnlr(y,"exponential",pmu=c(8,-1,0,0),mu=mu)
gnlr(y,"Weibull",pmu=c(8,-1,0,0),pshape=0,mu=mu)

mu <- function(p) exp(p[1]+p[2]*bk)
shape <- function(p) p[1]+p[2]*bk
gnlr(y,"Weibull",pmu=c(8,-1),pshape=c(0,0),mu=mu,shape=shape)
mu <- function(p) exp(p[1]+p[2]*bk+p[3]*birth)
shape <- function(p) p[1]+p[2]*bk+p[3]*birth
gnlr(y,"Weibull",pmu=c(8,-1,0),pshape=c(0,0,0),mu=mu,shape=shape)
mu <- function(p) exp(p[1]+p[2]*bk+p[3]*birth+p[4]*bk*birth)
shape <- function(p) p[1]+p[2]*bk+p[3]*birth+p[4]*bk*birth
gnlr(y,"Weibull",pmu=c(8,-1,0,0),pshape=c(0,0,0,0),mu=mu,shape=shape)
mu <- function(p) exp(p[1]+p[2]*bk+p[3]*birth)
shape <- function(p) p[1]+p[2]*birth
gnlr(y,"Weibull",pmu=c(8,-1,0),pshape=c(0,0),mu=mu,shape=shape)
mu <- function(p) exp(p[1]+p[2]*bk+p[3]*birth+p[4]*bk*birth)
gnlr(y,"Weibull",pmu=c(8,-1,0,0),pshape=c(0,0),mu=mu,shape=shape)
